@@ -50,21 +50,21 @@ class TestMultiStore(base.MultiStoreBaseTest,
     def setUp(self):
         """Establish a clean test environment."""
         super(TestMultiStore, self).setUp()
-        enabled_backends = {
+        self.enabled_backends = {
             "file1": "file",
             "file2": "file",
         }
         self.conf = self._CONF
         self.conf(args=[])
         self.conf.register_opt(cfg.DictOpt('enabled_backends'))
-        self.config(enabled_backends=enabled_backends)
+        self.config(enabled_backends=self.enabled_backends)
         store.register_store_opts(self.conf)
         self.config(default_backend='file1', group='glance_store')
 
         # Ensure stores + locations cleared
         location.SCHEME_TO_CLS_BACKEND_MAP = {}
-
         store.create_multi_stores(self.conf)
+
         self.addCleanup(setattr, location, 'SCHEME_TO_CLS_BACKEND_MAP',
                         dict())
         self.test_dir = self.useFixture(fixtures.TempDir()).path
@@ -96,6 +96,10 @@ class TestMultiStore(base.MultiStoreBaseTest,
         return self.store.add(expected_image_id, image_file,
                               expected_file_size)
 
+    def test_location_url_prefix_is_set(self):
+        expected_url_prefix = "file://%s" % self.test_dir
+        self.assertEqual(expected_url_prefix, self.store.url_prefix)
+
     def test_get(self):
         """Test a "normal" retrieval of an image in chunks."""
         # First add an image...
@@ -106,7 +110,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         loc, size, checksum, metadata = self.store.add(
             image_id, image_file, len(file_contents))
         # Check metadata contains 'file1' as a backend
-        self.assertEqual(u"file1", metadata['backend'])
+        self.assertEqual(u"file1", metadata['store'])
 
         # Now read it back...
         uri = "file:///%s/%s" % (self.test_dir, image_id)
@@ -136,7 +140,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
                                                        image_file,
                                                        len(file_contents))
         # Check metadata contains 'file1' as a backend
-        self.assertEqual(u"file1", metadata['backend'])
+        self.assertEqual(u"file1", metadata['store'])
 
         # Now read it back...
         uri = "file:///%s/%s" % (self.test_dir, image_id)
@@ -197,7 +201,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         self.assertEqual(expected_location, loc)
         self.assertEqual(expected_file_size, size)
         self.assertEqual(expected_checksum, checksum)
-        self.assertEqual(u"file1", metadata['backend'])
+        self.assertEqual(u"file1", metadata['store'])
 
         uri = "file:///%s/%s" % (self.test_dir, expected_image_id)
         loc = location.get_location_from_uri_and_backend(
@@ -237,7 +241,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         self.assertEqual(expected_location, loc)
         self.assertEqual(expected_file_size, size)
         self.assertEqual(expected_checksum, checksum)
-        self.assertEqual(u"file2", metadata['backend'])
+        self.assertEqual(u"file2", metadata['store'])
 
         uri = "file:///%s/%s" % (self.test_dir, expected_image_id)
         loc = location.get_location_from_uri_and_backend(
@@ -257,20 +261,20 @@ class TestMultiStore(base.MultiStoreBaseTest,
         in_metadata = [{'id': 'abcdefg',
                        'mountpoint': '/xyz/images'}]
         location, size, checksum, metadata = self._store_image(in_metadata)
-        self.assertEqual({'backend': u'file1'}, metadata)
+        self.assertEqual({'store': u'file1'}, metadata)
 
     def test_add_check_metadata_list_with_invalid_mountpoint_locations(self):
         in_metadata = [{'id': 'abcdefg', 'mountpoint': '/xyz/images'},
                        {'id': 'xyz1234', 'mountpoint': '/pqr/images'}]
         location, size, checksum, metadata = self._store_image(in_metadata)
-        self.assertEqual({'backend': u'file1'}, metadata)
+        self.assertEqual({'store': u'file1'}, metadata)
 
     def test_add_check_metadata_list_with_valid_mountpoint_locations(self):
         in_metadata = [{'id': 'abcdefg', 'mountpoint': '/tmp'},
                        {'id': 'xyz1234', 'mountpoint': '/xyz'}]
         location, size, checksum, metadata = self._store_image(in_metadata)
         self.assertEqual(in_metadata[0], metadata)
-        self.assertEqual(u"file1", metadata["backend"])
+        self.assertEqual(u"file1", metadata["store"])
 
     def test_add_check_metadata_bad_nosuch_file(self):
         expected_image_id = str(uuid.uuid4())
@@ -287,7 +291,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
                                                             image_file,
                                                             expected_file_size)
 
-        self.assertEqual({'backend': u'file1'}, metadata)
+        self.assertEqual({'store': u'file1'}, metadata)
 
     def test_add_already_existing(self):
         """
@@ -303,7 +307,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         location, size, checksum, metadata = self.store.add(image_id,
                                                             image_file,
                                                             file_size)
-        self.assertEqual(u"file1", metadata["backend"])
+        self.assertEqual(u"file1", metadata["store"])
 
         image_file = six.BytesIO(b"nevergonnamakeit")
         self.assertRaises(exceptions.Duplicate,
@@ -388,7 +392,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         loc, size, checksum, metadata = self.store.add(image_id,
                                                        image_file,
                                                        file_size)
-        self.assertEqual(u"file1", metadata["backend"])
+        self.assertEqual(u"file1", metadata["store"])
 
         # Now check that we can delete it
         uri = "file:///%s/%s" % (self.test_dir, image_id)
@@ -417,7 +421,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         loc, size, checksum, metadata = self.store.add(image_id,
                                                        image_file,
                                                        file_size)
-        self.assertEqual(u"file1", metadata["backend"])
+        self.assertEqual(u"file1", metadata["store"])
 
         uri = "file:///%s/%s" % (self.test_dir, image_id)
         loc = location.get_location_from_uri_and_backend(uri, "file1",
@@ -587,7 +591,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         loc, size, checksum, metadata = self.store.add(expected_image_id,
                                                        image_file,
                                                        expected_file_size)
-        self.assertEqual(u"file1", metadata["backend"])
+        self.assertEqual(u"file1", metadata["store"])
 
         self.assertEqual(expected_location, loc)
         self.assertEqual(expected_file_size, size)
@@ -634,7 +638,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         loc, size, checksum, metadata = self.store.add(expected_image_id,
                                                        image_file,
                                                        expected_file_size)
-        self.assertEqual(u"file1", metadata["backend"])
+        self.assertEqual(u"file1", metadata["store"])
 
         self.assertEqual(expected_location, loc)
         self.assertEqual(expected_file_size, size)
@@ -745,7 +749,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         location, size, checksum, metadata = self.store.add(expected_image_id,
                                                             image_file,
                                                             expected_file_size)
-        self.assertEqual(u"file1", metadata["backend"])
+        self.assertEqual(u"file1", metadata["store"])
 
         self.assertEqual(expected_location, location)
         self.assertEqual(expected_file_size, size)
@@ -789,7 +793,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         location, size, checksum, metadata = self.store.add(expected_image_id,
                                                             image_file,
                                                             expected_file_size)
-        self.assertEqual(u"file1", metadata["backend"])
+        self.assertEqual(u"file1", metadata["store"])
 
         self.assertEqual(expected_location, location)
         self.assertEqual(expected_file_size, size)
